# frozen_string_literal: true

module ZuoraObservability
  # The ZuoraObservability Engine is mounted to hook into Rails
  class Engine < ::Rails::Engine
    isolate_namespace ZuoraObservability

    config.generators do |g|
      g.test_framework :rspec
    end

    initializer(:rails_stdout_logging, before: :initialize_logger) do
      Rails.application.configure do
        config.logger = ZuoraObservability::Logger.custom_logger(name: 'Rails')

        next unless ZuoraObservability.configuration.json_logging

        config.logger = ActiveSupport::TaggedLogging.new(config.logger)

        require 'lograge'
        require 'zuora_observability/logging/custom_options'

        config.lograge.enabled = true
        config.colorize_logging = false

        config.lograge.formatter = Lograge::Formatters::Raw.new

        config.lograge.custom_options = Logging::CustomOptions
        config.lograge.custom_payload do |controller|
          payload = {}

          ZuoraObservability.configuration.custom_payload_hooks.each do |hook|
            payload.merge!(hook.call(controller))
          end

          next payload unless ZuoraObservability.configuration.zecs_service_hook

          payload[:zecs_service] =
            ZuoraObservability.configuration.zecs_service_hook.call(controller)

          payload
        end
      end
    end
  end
end
