# frozen_string_literal: true

module ZuoraObservability
  # Methods to get information about the application environment
  class Env
    class << self
      def name
        ENV['Z_APPLICATION_NAME']
      end

      def version
        ENV['Z_APPLICATION_VERSION']
      end

      def environment
        ENV['Z_APPLICATION_ENVIRONMENT']
      end

      def app_name
        ENV['DEIS_APP'].presence || app_parent_name
      end

      def pod_name
        ENV['HOSTNAME'].presence || Socket.gethostname
      end

      def full_process_name(process_name: nil, function: nil)
        keys = [pod_name, process_name.presence || process_type, Process.pid, function]
        keys.compact.join('][').prepend('[').concat(']')
      end

      # Returns the process type if any
      def process_type(default: 'Unknown')
        p_type = default
        if ENV['HOSTNAME'] && ENV['DEIS_APP']
          temp = ENV['HOSTNAME'].split(ENV['DEIS_APP'])[1]
          temp = temp.split(/(-[0-9a-zA-Z]{5})$/)[0] # remove the 5 char hash
          p_type = temp[1, temp.rindex("-")-1]
        end
        return p_type
      end

      private

      def app_parent_name
        if Rails::VERSION::MAJOR >= 6
          Rails.application.class.module_parent_name
        else
          Rails.application.class.parent_name
        end
      end
    end
  end
end
