# frozen_string_literal: true

module ZuoraObservability
  # Methods to gather and format metrics
  module Metrics
    class << self
      def resque
        Resque.redis.ping

        resque = Resque.info

        {
          app_name: ZuoraObservability::Env.app_name, url: 'dummy', Resque: {
            Jobs_Finished: resque[:processed], Jobs_Failed: resque[:failed],
            Jobs_Pending: resque[:pending], Workers_Active: resque[:working],
            Workers_Total: resque[:workers]
          }
        }
      end

      def versions
        {
          app_name: ZuoraObservability::Env.app_name,
          url: 'dummy',
          Version_Gem: ZuoraConnect::VERSION,
          Version_Zuora: ZuoraAPI::VERSION,
          Version_Ruby: RUBY_VERSION,
          Version_Rails: Rails.version,
          hold: 1
        }
      end

      def unicorn_listener
        stats_hash = {}
        stats_hash["total_active"] = 0
        stats_hash["total_queued"] = 0

        begin
          tmp = Unicorn.listener_names
          unix = tmp.grep(%r{\A/})
          tcp = tmp.grep(/\A.+:\d+\z/)
          tcp = nil if tcp.empty?
          unix = nil if unix.empty?


          Raindrops::Linux.tcp_listener_stats(tcp).each do |addr,stats|
            stats_hash["active_#{addr}"] = stats.active
            stats_hash["queued_#{addr}"] = stats.queued
            stats_hash["total_active"] = stats.active + stats_hash["total_active"]
            stats_hash["total_queued"] = stats.queued + stats_hash["total_queued"]
          end if tcp

          Raindrops::Linux.unix_listener_stats(unix).each do |addr,stats|
            stats_hash["active_#{addr}"] = stats.active
            stats_hash["queued_#{addr}"] = stats.queued
            stats_hash["total_active"] = stats.active + stats_hash["total_active"]
            stats_hash["total_queued"] = stats.queued + stats_hash["total_queued"]
          end if unix
        rescue IOError => ex
        rescue => ex
          Rails.logger.error(ex)
          puts ex
        end
        return stats_hash
      end
    end
  end
end
